@@ -23,9 +23,12 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
+#if defined(TIMIP___W32__)  && !defined(STDOUT_FILENO)
+#define STDOUT_FILENO 1
+#endif
 
 #if defined(__MINGW32__) && defined(USE_PDCURSES)
 #define _NO_OLDNAMES 1	/* avoid type mismatch timip_of beep() */
@@ -51,9 +54,9 @@ extern void sleep(unsigned long);
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 
-#ifdef __W32__
+#ifdef TIMIP___W32__
 #include <windows.h>
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 
 #ifdef HAVE_NCURSES_H
 #include <ncurses.h>
@@ -176,6 +179,7 @@ static int ctl_open(int using_stdin, int using_stdout);
 static void ctl_close(void);
 static void ctl_pass_playing_list(int number_of_files, char *list_of_files[]);
 static int ctl_read(int32 *valp);
+static int ctl_write(char *valp, int32 size);
 static int cmsg(int type, int verbosity_level, char *fmt, ...);
 static void ctl_event(CtlEvent *e);
 
@@ -253,6 +257,7 @@ ControlMode timip_ctl=
     ctl_close,
     ctl_pass_playing_list,
     ctl_read,
+    ctl_write,
     cmsg,
     ctl_event
 };
@@ -2867,6 +2872,17 @@ static int ctl_read(int32 *valp)
   return RC_NONE;
 }
 
+static int ctl_write(char *valp, int32 size)
+{
+  static int warned = 0;
+  if (!warned) {
+    fprintf(stderr, "Warning: using stdout with ncurses interface will not\n"
+		    "give the desired effect.\n");
+    warned = 1;
+  }
+  return write(STDOUT_FILENO, valp, size);
+}
+
 #ifdef USE_PDCURSES
 static void vwprintw(WINDOW *w, char *fmt, va_list ap)
 {
@@ -2897,7 +2913,7 @@ static int cmsg(int type, int verbosity_level, char *fmt, ...)
     }
     else
     {
-#if defined( __BORLANDC__) || (defined(__W32__) && !defined(__CYGWIN32__))
+#if defined( __BORLANDC__) || (defined(TIMIP___W32__) && !defined(__CYGWIN32__))
 	nl();
 #endif
 	if(timip_ctl.trace_playing)
@@ -3275,7 +3291,7 @@ static void update_indicator(void)
 		display_intonation(-1);
 	}
     play_modeflag = !play_modeflag;
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 
     t = timip_get_current_calender_time();
     if(indicator_mode != INDICATOR_DEFAULT)
