@@ -39,7 +39,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
@@ -74,6 +74,8 @@
 #include "timip_aq.h"
 #include "timip_timer.h"
 
+#define SERVER_VERSION"1.0.2"
+
 /* #define DEBUG_DUMP_SEQ 1 */
 #define MIDI_COMMAND_PER_SEC	100
 #define DEFAULT_LOW_TIMEAT	0.4
@@ -174,6 +176,7 @@ SYNTH [gus|awe]\n\
 static int ctl_open(int using_stdin, int using_stdout);
 static void ctl_close(void);
 static int ctl_read(int32 *valp);
+static int ctl_write(char *buffer, int32 size);
 static int cmsg(int type, int verbosity_level, char *fmt, ...);
 static void ctl_event(CtlEvent *e);
 static void ctl_pass_playing_list(int n, char *args[]);
@@ -193,6 +196,7 @@ ControlMode timip_ctl=
     ctl_close,
     ctl_pass_playing_list,
     ctl_read,
+    ctl_write,
     cmsg,
     ctl_event
 };
@@ -229,19 +233,18 @@ static int tmr_running;
 
 static int is_system_prefix = 0;
 static struct sockaddr_in control_client;
-static double low_time_at = 0.3;
-static double high_time_at = 0.5;
-static FILE *outfp;
+static double low_time_at = DEFAULT_LOW_TIMEAT;
+static double high_time_at = DEFAULT_HIGH_TIMEAT;
+static FILE *outfp = NULL;
+
+#define CONTROL_FD_OUT (control_port ? control_fd : STDOUT_FILENO)
 
 /*ARGSUSED*/
 static int ctl_open(int using_stdin, int using_stdout)
 {
     timip_ctl.opened = 1;
     timip_ctl.flags &= ~(CTLF_LIST_RANDOM|CTLF_LIST_SORT);
-    if(using_stdout)
-	outfp = stderr;
-    else
-	outfp = stdout;
+    outfp = stderr;
     return 0;
 }
 
@@ -269,6 +272,18 @@ static int ctl_read(int32 *valp)
     return RC_NONE;
 }
 
+static int ctl_write(char *buffer, int32 size)
+{
+    static int warned = 0;
+    if (!warned) {
+	fprintf(stderr, "Warning: STDOUT redirected to data socket\n");
+	warned = 1;
+    }
+    if(data_fd != -1)
+	return send(data_fd, buffer, size, MSG_DONTWAIT);
+    return -1;
+}
+
 static int cmsg(int type, int verbosity_level, char *fmt, ...)
 {
     va_list ap;
@@ -325,7 +340,7 @@ static int pasv_open(int *port)
     }
     if(*port == 0)
     {
-	int len = sizeof(server);
+	socklen_t len = sizeof(server);
 	if(getsockname(sfd, (struct sockaddr *)&server, &len) < 0)
 	{
 	    perror("getsockname");
@@ -367,10 +382,6 @@ static void ctl_pass_playing_list(int n, char *args[])
 	return;
     }
 
-#ifdef SIGPIPE
-    signal(SIGPIPE, SIG_IGN);    /* Handle broken pipe */
-#endif /* SIGPIPE */
-
     control_port = atoi(args[0]);
     if(n == 2)
 	data_port = atoi(args[1]);
@@ -378,6 +389,9 @@ static void ctl_pass_playing_list(int n, char *args[])
 	data_port = 0;
 
     if (control_port) {
+#ifdef SIGPIPE
+	signal(SIGPIPE, SIG_IGN);    /* Handle broken pipe */
+#endif /* SIGPIPE */
 	sock = pasv_open(&control_port);
 	if(sock == -1)
 	    return;
@@ -391,7 +405,7 @@ static void ctl_pass_playing_list(int n, char *args[])
     timip_play_mode->close_output();
     while(1)
     {
-	int addrlen;
+	socklen_t addrlen;
 
 	addrlen = sizeof(control_client);
 	memset(&control_client, 0, addrlen);
@@ -419,7 +433,7 @@ static void ctl_pass_playing_list(int n, char *args[])
 			timip_play_mode->id_name, timip_play_mode->id_character);
 	    if (control_port) {
 		close(control_fd);
-		control_fd = 1;
+		control_fd = -1;
 	    }
 	    continue;
 	}
@@ -488,7 +502,7 @@ static int send_status(int status, char *message, ...)
     va_end(ap);
     strncat(buff, "\n", BUFSIZ - strlen(buff) - 1);
     buff[BUFSIZ-1] = '\0';      /* force terminate */
-    if(write(control_fd, buff, strlen(buff)) == -1)
+    if(write(CONTROL_FD_OUT, buff, strlen(buff)) == -1)
 	return -1;
     return 0;
 }
@@ -506,9 +520,8 @@ static void seq_play_event(MidiEvent *timip_ev)
 	}
 	else
 	{
-	    double past_time = timip_get_current_calender_time() - start_time;
-	    if(timip_play_mode->flag & PF_PCM_STREAM)
-		past_time += high_time_at;
+	    double past_time = timip_get_current_calender_time() - start_time -
+		    (double)(curr_event_samples + event_time_offset) / timip_play_mode->rate;
 	    timip_ev->time = (int32)(past_time * timip_play_mode->rate);
 	}
     }
@@ -603,9 +616,9 @@ static void doit(void)
     memset(&control_fd_buffer, 0, sizeof(control_fd_buffer));
     control_fd_buffer.fd = control_fd;
 
-    send_status(220, "TiMidity++ %s%s ready",
+    send_status(220, "TiMidity++ %s%s ready (Server Version %s)",
     		(strcmp(timip_timidity_version, "current")) ? "v" : "",
-    		timip_timidity_version);
+    		timip_timidity_version, SERVER_VERSION);
 
 /*    while(data_fd != -1 && control_fd != -1) */
     while(control_fd != -1)
@@ -635,18 +648,16 @@ static void doit(void)
 		    double wait_time;
 		    int32 filled;
 
-		    filled = timip_aq_filled();
-		    if(!tmr_running && filled <= 0)
-			usec = -1;
+		    if (IS_STREAM_TRACE)
+			filled = timip_aq_filled();
 		    else
-		    {
-			wait_time = (double)filled / timip_play_mode->rate
-			    - low_time_at;
-			if(wait_time <= 0)
-			    usec = 0;
-			else
-			    usec = (long)(wait_time * 1000000);
-		    }
+			filled = high_time_at * timip_play_mode->rate;
+
+		    wait_time = (double)filled / timip_play_mode->rate - low_time_at;
+		    if(wait_time <= 0)
+			usec = 0;
+		    else
+			usec = (long)(wait_time * 1000000);
 	    }
 	    else
 		usec = -1;
@@ -669,11 +680,6 @@ static void doit(void)
 
 	    if(n == 0)
 	    {
-		if(timip_ctl.verbosity >= VERB_DEBUG)
-		{
-		    putchar(',');
-		    fflush(stdout);
-		}
 		do_timeout();
 		continue;
 	    }
@@ -706,10 +712,14 @@ static void do_timeout(void)
 {
     double fill_time;
 
-    if(data_fd == -1 || !IS_STREAM_TRACE)
+    if(data_fd == -1)
 	return;
     timip_aq_add(NULL, 0);
-    fill_time = high_time_at - (double)timip_aq_filled() / timip_play_mode->rate;
+    if (IS_STREAM_TRACE)
+	fill_time = high_time_at - (double)timip_aq_filled() / timip_play_mode->rate;
+    else
+	fill_time = timip_get_current_calender_time() - start_time -
+		(double)(curr_event_samples + event_time_offset) / timip_play_mode->rate;
     if(fill_time <= 0)
 	return;
 
@@ -837,19 +847,19 @@ static int cmd_help(int argc, char **argv)
 
     for(i = 0; cmd_table[i].cmd; i++)
     {
-	if(fdputs(cmd_table[i].help, control_fd))
+	if(fdputs(cmd_table[i].help, CONTROL_FD_OUT))
 	    return -1;
-	if(fdputs("\n", control_fd))
+	if(fdputs("\n", CONTROL_FD_OUT))
 	    return -1;
     }
-    return fdputs(".\n", control_fd);
+    return fdputs(".\n", CONTROL_FD_OUT);
 }
 
 static int cmd_open(int argc, char **argv)
 {
     int sock;
     struct sockaddr_in in;
-    int addrlen;
+    socklen_t addrlen;
     int port;
 
     if(data_fd != -1)
@@ -1011,7 +1021,7 @@ static int cmd_autoreduce(int argc, char **argv)
 static int cmd_setbuf(int argc, char **argv)
 {
     low_time_at = atof(argv[1]);
-    high_time_at = atof(argv[1]);
+    high_time_at = atof(argv[2]);
     return send_status(200, "OK");
 }
 
@@ -1142,8 +1152,8 @@ static int do_sequencer(void)
     {
 	int i;
 	for(i = 0; i < n; i++)
-	    printf("%02x", data_buffer[data_buffer_len + i]);
-	putchar('\n');
+	    fprintf(stderr, "%02x", data_buffer[data_buffer_len + i]);
+	fprintf(stderr, "\n");
     }
 #endif /* DEBUG_DUMP_SEQ */
 
@@ -1484,7 +1494,7 @@ static void do_timing(uint8 *data)
       case TMR_WAIT_ABS:
 
 /*
-   printf("## TMR_WAIT_ABS: %d %d %d %g\n",
+   fprintf(stderr, "## TMR_WAIT_ABS: %d %d %d %g\n",
        curr_tick,
        curr_tick - (time2tick(timip_get_current_calender_time()
 			      - start_time) + tick_offs),
@@ -1505,7 +1515,7 @@ static void do_timing(uint8 *data)
       case TMR_SPP:
 #endif
       default:
-/* printf("## TMR=0x%02x is not supported\n", data[1]); */
+/* fprintf(stderr, "## TMR=0x%02x is not supported\n", data[1]); */
 	break;
     }
 }
