@@ -39,7 +39,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
@@ -130,6 +130,7 @@ static void ctl_reset(void);
 static int ctl_open(int using_stdin, int using_stdout);
 static void ctl_close(void);
 static int ctl_read(int32 *valp);
+static int ctl_write(char *valp, int32 size);
 static void ctl_lyric(int valp);
 static int cmsg(int type, int verbosity_level, char *fmt, ...);
 static void ctl_event(CtlEvent *e);
@@ -149,6 +150,7 @@ ControlMode timip_ctl=
     ctl_close,
     timip_dumb_pass_playing_list,
     ctl_read,
+    ctl_write,
     cmsg,
     ctl_event
 };
@@ -587,6 +589,17 @@ static int ctl_read(int32 *valp)
   return RC_NONE;
 }
 
+static int ctl_write(char *valp, int32 size)
+{
+  static int warned = 0;
+  if (!warned) {
+    fprintf(stderr, "Warning: using stdout with slang interface will not\n"
+		    "give the desired effect.\n");
+    warned = 1;
+  }
+  return write(STDOUT_FILENO, valp, size);
+}
+
 /*ARGSUSED*/
 static void ctl_lyric(int lyricid)
 {
