@@ -21,7 +21,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
@@ -42,7 +42,7 @@
 #include <sys/time.h>
 #endif /* HAVE_SYS_TIME_H */
 
-#ifdef __W32__
+#ifdef TIMIP___W32__
 #include <windows.h>
 #endif
 
@@ -812,7 +812,7 @@ static int cmsg(int type, int verbosity_level, char *fmt, ...)
     return 0;
 }
 
-#if !defined(__W32__) || defined(__CYGWIN32__)
+#if !defined(TIMIP___W32__) || defined(__CYGWIN32__)
 /* UNIX */
 static char *vt100_getline(void)
 {
