@@ -25,9 +25,9 @@
 #include <stdlib.h>
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
-#include "interface.h"
+#include "timip_interface.h"
 #include "timip_timidity.h"
 #include "timip_common.h"
 #include "timip_output.h"
@@ -181,7 +181,7 @@ void LoadIniFile(SETTING_PLAYER *sp,  SETTING_TIMIDITY *st)
     IniGetKeyStringN(INI_SEC_TIMIDITY,"output_text_code",st->timip_output_text_code,sizeof(st->timip_output_text_code)-1);
     IniGetKeyInt(INI_SEC_TIMIDITY,"free_instruments_afterwards",&(st->timip_free_instruments_afterwards));
     IniGetKeyStringN(INI_SEC_TIMIDITY,"out_wrd",st->opt_wrd,sizeof(st->opt_wrd)-1);
-#if defined(__W32__) && defined(SMFCONV)
+#if defined(TIMIP___W32__) && defined(SMFCONV)
     IniGetKeyInt(INI_SEC_TIMIDITY,"opt_rcpcv_dll",&(st->opt_rcpcv_dll));
 #endif
     IniGetKeyInt(INI_SEC_TIMIDITY,"data_block_bits",&(st->data_block_bits));
@@ -321,7 +321,7 @@ SaveIniFile(SETTING_PLAYER *sp,  SETTING_TIMIDITY *st)
     IniPutKeyStringN(INI_SEC_TIMIDITY,"output_text_code",st->timip_output_text_code,sizeof(st->timip_output_text_code));
     IniPutKeyInt(INI_SEC_TIMIDITY,"free_instruments_afterwards",&(st->timip_free_instruments_afterwards));
     IniPutKeyStringN(INI_SEC_TIMIDITY,"out_wrd",st->opt_wrd,sizeof(st->opt_wrd));
-#if defined(__W32__) && defined(SMFCONV)
+#if defined(TIMIP___W32__) && defined(SMFCONV)
     IniPutKeyInt(INI_SEC_TIMIDITY,"opt_rcpcv_dll",&(st->opt_rcpcv_dll));
 #endif
     IniPutKeyInt(INI_SEC_TIMIDITY,"data_block_bits",&(st->data_block_bits));
