@@ -21,7 +21,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
@@ -1363,11 +1363,13 @@ stage1_end:
  	default:
 		strncpy(out,buffer,MAX2(buffer_size-1,out_size-1));
 		out[out_size-1] = '\0';
+		free(buffer);
 		break;
 	case LANGUAGE_JAPANESE:
 		strncpy(out,buffer,MAX2(buffer_size-1,out_size-1));
 		timip_nkf_convert(buffer,out,out_size-1,NULL,"SJIS");
 		out[out_size-1] = '\0';
+		free(buffer);
 		break;
 	}
 }
@@ -1825,3 +1827,8 @@ void w32g_setup_doc(int idx)
 		return;
 	DocWndSetMidifile(filename);
 }
+
+void w32g_free_doc(void)
+{
+	if(DocWndInfo.Text != NULL) free(DocWndInfo.Text);
+}
