@@ -21,9 +21,9 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
-#include "interface.h"
+#include "timip_interface.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -66,6 +66,9 @@ int WINAPI timeKillEvent(UINT uTimerID);
 
 #ifdef TWSYNSRV
 #include <winsvc.h>
+#ifdef __DMC__
+#define SERVICE_ACCEPT_PARAMCHANGE    8
+#endif
 //#include <lmcons.h>
 #include <stdarg.h>
 #endif
@@ -209,7 +212,7 @@ static int w32g_syn_create_win ( void );
 #define IDM_TIMIDITY 127
 
 #ifdef HAVE_SYN_CONSOLE
-static HWND hConsoleWnd;
+HWND hConsoleWnd;
 void InitConsoleWnd(HWND hParentWnd);
 #endif // HAVE_SYN_CONSOLE
 
