@@ -19,7 +19,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <windows.h>
 #include <stdlib.h>
@@ -41,7 +41,7 @@
 #include "timip_w32g.h"
 #include "timip_w32g_ut2.h"
 
-char *timidity_window_inifile;
+extern char *timidity_window_inifile;
 
 // ****************************************************************************
 // DlgChooseFont
@@ -862,7 +862,7 @@ int w32gSecondTiMidityExit(void)
 	return 0;
 }
 
-// Before it call timip_timidity_start_initialize()
+// Before it call timidity_start_initialize()
 int isURLFile(char *filename)
 {
 	if(strncasecmp(filename,"http://",7)==0
