@@ -23,9 +23,9 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
-#include "interface.h"
+#include "timip_interface.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -468,7 +468,7 @@ extern int set_tim_opt(int c, char *optarg);
 extern int timip_set_ctl(char *cp);
 extern int timip_set_wrd(char *w);
 
-#if defined(__W32__) && defined(SMFCONV)
+#if defined(TIMIP___W32__) && defined(SMFCONV)
 extern int opt_rcpcv_dll;
 #endif /* SMFCONV */
 extern char *timip_wrdt_open_opts;
@@ -561,6 +561,7 @@ ApplySettingTiMidity(SETTING_TIMIDITY *st)
     else if(timip_play_mode->rate == 0)
 	timip_play_mode->rate = DEFAULT_RATE;
     voices = st->voices;
+	if( voices > timip_max_voices) timip_max_voices = voices;
 	timip_auto_reduce_polyphony = st->timip_auto_reduce_polyphony;
     timip_quietchannels = st->timip_quietchannels;
     timip_temper_type_mute = st->timip_temper_type_mute;
@@ -585,7 +586,7 @@ ApplySettingTiMidity(SETTING_TIMIDITY *st)
     timip_output_text_code = timip_safe_strdup(st->timip_output_text_code);
     timip_free_instruments_afterwards = st->timip_free_instruments_afterwards;
     timip_set_wrd(st->opt_wrd);
-#if defined(__W32__) && defined(SMFCONV)
+#if defined(TIMIP___W32__) && defined(SMFCONV)
     opt_rcpcv_dll = st->opt_rcpcv_dll;
 #endif /* SMFCONV */
 
@@ -743,7 +744,7 @@ SaveSettingTiMidity(SETTING_TIMIDITY *st)
 	strncpy(st->opt_wrd + 1, timip_wrdt_open_opts, sizeof(st->opt_wrd) - 2);
     else
 	st->opt_wrd[1] = '\0';
-#if defined(__W32__) && defined(SMFCONV)
+#if defined(TIMIP___W32__) && defined(SMFCONV)
     st->opt_rcpcv_dll = opt_rcpcv_dll;
 #endif /* SMFCONV */
   st->data_block_bits = data_block_bits;
@@ -780,7 +781,7 @@ static char S_ConfigFileOpenDir[MAXPATH + 32];
 static char S_PlaylistFileOpenDir[MAXPATH + 32];
 static char S_DocFileExt[256];
 static char S_OutputName[MAXPATH + 32];
-static char *OutputName;
+char *OutputName;
 static char S_w32g_output_dir[1024 + 32];
 static char S_SystemFont[256];
 static char S_PlayerFont[256];
@@ -788,12 +789,12 @@ static char S_WrdFont[256];
 static char S_DocFont[256];
 static char S_ListFont[256];
 static char S_TracerFont[256];
-static char *SystemFont = S_SystemFont;
+char *SystemFont = S_SystemFont;
 char *PlayerFont = S_PlayerFont;
-static char *WrdFont = S_WrdFont;
-static char *DocFont = S_DocFont;
-static char *ListFont = S_ListFont;
-static char *TracerFont = S_TracerFont;
+char *WrdFont = S_WrdFont;
+char *DocFont = S_DocFont;
+char *ListFont = S_ListFont;
+char *TracerFont = S_TracerFont;
 
 //static HFONT hSystemFont = 0;
 //static HFONT hPlayerFont = 0;
@@ -801,21 +802,21 @@ static char *TracerFont = S_TracerFont;
 //static HFONT hDocFont = 0;
 //static HFONT hListFont = 0;
 //static HFONT hTracerFont = 0;
-static int SystemFontSize = 9;
-static int PlayerFontSize = 16;
-static int WrdFontSize = 16;
-static int DocFontSize = 16;
-static int ListFontSize = 16;
-static int TracerFontSize = 16;
+int SystemFontSize = 9;
+int PlayerFontSize = 16;
+int WrdFontSize = 16;
+int DocFontSize = 16;
+int ListFontSize = 16;
+int TracerFontSize = 16;
 
 #define DEFAULT_DOCFILEEXT "doc;txt;hed"
 
-SETTING_PLAYER *sp_default, *sp_current, *sp_temp;
-SETTING_TIMIDITY *st_default, *st_current, *st_temp;
+SETTING_PLAYER *sp_default=NULL, *sp_current=NULL, *sp_temp=NULL;
+SETTING_TIMIDITY *st_default=NULL, *st_current=NULL, *st_temp=NULL;
 char *timidity_window_inifile;
 char *timidity_output_inifile;
 
-#ifdef AU_GOGO
+#ifdef TIMIP_AU_GOGO
 extern int gogo_ConfigDialogInfoInit(void);
 extern int gogo_ConfigDialogInfoSaveINI(void);
 extern int gogo_ConfigDialogInfoLoadINI(void);
@@ -826,6 +827,16 @@ extern int vorbis_ConfigDialogInfoSaveINI(void);
 extern int vorbis_ConfigDialogInfoLoadINI(void);
 #endif
 
+void w32g_uninitialize(void)
+{
+	if(sp_default != NULL) free(sp_default);
+	if(st_default != NULL) free(st_default);
+	if(sp_current != NULL) free(sp_current);
+	if(st_current != NULL) free(st_current);
+	if(sp_temp != NULL) free(sp_temp);
+	if(st_temp != NULL) free(st_temp);
+}
+
 void w32g_initialize(void)
 {
     char buffer[MAXPATH + 1024];
@@ -911,7 +922,7 @@ void w32g_initialize(void)
 
 	{
 		DWORD dwRes;
-#ifdef AU_GOGO
+#ifdef TIMIP_AU_GOGO
 		gogo_ConfigDialogInfoInit();
 #endif
 #ifdef AU_VORBIS
@@ -919,14 +930,14 @@ void w32g_initialize(void)
 #endif
 		dwRes = GetFileAttributes(timidity_output_inifile);
 		if(dwRes==0xFFFFFFFF || dwRes & FILE_ATTRIBUTE_DIRECTORY){
-#ifdef AU_GOGO
+#ifdef TIMIP_AU_GOGO
 			gogo_ConfigDialogInfoSaveINI();
 #endif
 #ifdef AU_VORBIS
 			vorbis_ConfigDialogInfoSaveINI();
 #endif
 		} else {
-#ifdef AU_GOGO
+#ifdef TIMIP_AU_GOGO
 			gogo_ConfigDialogInfoLoadINI();
 #endif
 #ifdef AU_VORBIS
