@@ -24,7 +24,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
