@@ -19,7 +19,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #ifndef NO_STRING_H
 #include <string.h>
@@ -723,9 +723,9 @@ URL timip_url_arc_open(char *name)
 
     if((afl = find_arc_filelist(base)) == NULL)
 	afl = regist_archive(base);
+	timip_reuse_mblock(&arc_buffer);	/* free `base' */
     if(afl == NULL)
 	return NULL;
-    timip_reuse_mblock(&arc_buffer);	/* free `base' */
     name += len + 1;
     while(*name == '/') name++;	/* skip '/'s right after # (slash is always processed) */
 #if PATH_SEP != '/'
