@@ -19,7 +19,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 /* deflate.c -- compress data using the deflation algorithm
  * Copyright (C) 1992-1993 Jean-loup Gailly
