@@ -19,7 +19,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 /* timip_explode.c -- put in the public domain by Mark Adler
    version c15, 6 July 1996 */
