@@ -27,7 +27,7 @@
 ==============================================================================*/
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif
 
 #include <string.h>
