@@ -22,7 +22,7 @@
    */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
@@ -51,14 +51,14 @@
 #include <strings.h>
 #endif
 #include <ctype.h>
-#ifndef __W32__
+#ifndef TIMIP___W32__
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
 #else
 #include <process.h>
 #include <io.h>
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 #include "timip_timidity.h"
 #include "timip_common.h"
 #include "timip_output.h"
@@ -155,7 +155,7 @@ timip_tmdy_mkstemp(char *tmpl)
     v /= 62;
     XXXXXX[5] = letters[v % 62];
 
-#if defined(_MSC_VER)
+#if defined(_MSC_VER) || defined(__DMC__)
 #define S_IRUSR 0
 #define S_IWUSR 0
 #endif
@@ -265,10 +265,10 @@ struct timidity_file *timip_try_to_open(char *name, int decompress)
 	timip_url_cache_disable(tf->url);
     }
 
-#ifdef __W32__
+#ifdef TIMIP___W32__
     /* Sorry, DECOMPRESSOR_LIST and PATCH_CONVERTERS are not worked yet. */
     return tf;
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 
 #if defined(DECOMPRESSOR_LIST)
     if(decompress)
@@ -365,11 +365,11 @@ static int is_abs_path(const char *name)
 	if (!IS_PATH_SEP(name[0]) && strchr(name, PATH_SEP) != NULL)
 		return 1;
 #endif /* __MACOS__ */
-#ifdef __W32__
+#ifdef TIMIP___W32__
     /* [A-Za-z]: (for Windows) */
     if (isalpha(name[0]) && name[1] == ':')
 		return 1;
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 	if (timip_is_url_prefix(name))
 		return 1;	/* assuming relative notation is excluded */
 	return 0;
@@ -485,7 +485,7 @@ void timip_close_file(struct timidity_file *tf)
     int save_errno = errno;
     if(tf->url != NULL)
     {
-#ifndef __W32__
+#ifndef TIMIP___W32__
 	if(tf->tmpname != NULL)
 	{
 	    int i;
@@ -493,7 +493,7 @@ void timip_close_file(struct timidity_file *tf)
 	    for(i = 0; tf_getc(tf) != EOF && i < 0xFFFF; i++)
 		;
 	}
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 	timip_url_close(tf->url);
     }
     if(tf->tmpname != NULL)
@@ -855,7 +855,7 @@ static void code_convert_japan(char *in, char *out, int maxlen,
 	mode = timip_output_text_code;
 	if(mode == NULL || strstr(mode, "AUTO"))
 	{
-#ifndef __W32__
+#ifndef TIMIP___W32__
 	    mode = getenv("LANG");
 #else
 	    mode = "SJIS";
@@ -1218,7 +1218,7 @@ int timip_pathcmp(const char *p1, const char *p2, int ignore_case)
 {
     int c1, c2;
 
-#ifdef __W32__
+#ifdef TIMIP___W32__
     ignore_case = 1;	/* Always ignore the case */
 #endif
 
