@@ -23,7 +23,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #if HAVE_UNISTD_H
@@ -31,12 +31,12 @@
 #endif /* HAVE_UNISTD_H */
 #include <fcntl.h>
 
-#ifdef __W32__
+#ifdef TIMIP___W32__
 #include <io.h>
 #include <time.h>
 #endif
 
-#if defined(AU_FLAC_DLL) || defined(AU_OGGFLAC_DLL)
+#if defined(TIMIP_AU_FLAC_DLL) || defined(TIMIP_AU_OGGFLAC_DLL)
 #include <windows.h>
 #define FLAC__EXPORT_H  /* don't include "OggFLAC/export.h" */
 #define FLAC_API
@@ -49,10 +49,10 @@
 #include <OggFLAC/stream_encoder.h>
 #endif
 
-#ifdef AU_FLAC_DLL
+#ifdef TIMIP_AU_FLAC_DLL
 #include "timip_w32_libFLAC_dll_g.h"
 #endif
-#ifdef AU_OGGFLAC_DLL
+#ifdef TIMIP_AU_OGGFLAC_DLL
 #include "timip_w32_libOGGFLAC_dll_g.h"
 #endif
 
@@ -587,14 +587,14 @@ static int open_output(void)
 {
   int include_enc, exclude_enc;  
 
-#ifdef AU_FLAC_DLL
+#ifdef TIMIP_AU_FLAC_DLL
 	if (timip_g_load_libFLAC_dll("libFLAC.dll")) {
 		return -1;
 	}
 #endif
-#ifdef AU_OGGFLAC_DLL
+#ifdef TIMIP_AU_OGGFLAC_DLL
 	if (timip_g_load_libOggFLAC_dll("libOggFLAC.dll")) {
-#ifdef AU_FLAC_DLL
+#ifdef TIMIP_AU_FLAC_DLL
 		timip_g_free_libFLAC_dll ();
 #endif
 		return -1;
@@ -649,7 +649,7 @@ ogg_stream_encoder_write_callback(const OggFLAC__StreamEncoder *encoder,
 
   ctx->out_bytes += bytes;
 
-  if (write(dpm.fd, buffer, bytes) != -1)
+  if (timip_std_write(dpm.fd, buffer, bytes) != -1)
     return FLAC__STREAM_ENCODER_WRITE_STATUS_OK;
   else
     return FLAC__STREAM_ENCODER_WRITE_STATUS_FATAL_ERROR;
@@ -665,7 +665,7 @@ flac_stream_encoder_write_callback(const FLAC__StreamEncoder *encoder,
 
   ctx->out_bytes += bytes;
 
-  if (write(dpm.fd, buffer, bytes) == bytes)
+  if (timip_std_write(dpm.fd, buffer, bytes) == bytes)
     return FLAC__STREAM_ENCODER_WRITE_STATUS_OK;
   else
     return FLAC__STREAM_ENCODER_WRITE_STATUS_FATAL_ERROR;
@@ -685,7 +685,7 @@ flac_seekable_stream_encoder_write_callback(const FLAC__SeekableStreamEncoder *e
 
   ctx->out_bytes += bytes;
 
-  if (write(dpm.fd, buffer, bytes) == bytes)
+  if (timip_std_write(dpm.fd, buffer, bytes) == bytes)
     return FLAC__STREAM_ENCODER_WRITE_STATUS_OK;
   else
     return FLAC__STREAM_ENCODER_WRITE_STATUS_FATAL_ERROR;
@@ -844,10 +844,10 @@ static void close_output(void)
 
   flac_session_close();
 
-#ifdef AU_FLAC_DLL
+#ifdef TIMIP_AU_FLAC_DLL
 	timip_g_free_libFLAC_dll ();
 #endif
-#ifdef AU_OGGFLAC_DLL
+#ifdef TIMIP_AU_OGGFLAC_DLL
 	timip_g_free_libOggFLAC_dll ();
 #endif
 
