@@ -23,15 +23,15 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
-#include "interface.h"
+#include "timip_interface.h"
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef AU_GOGO
+#ifdef TIMIP_AU_GOGO
 
-#ifdef __W32__
+#ifdef TIMIP___W32__
 #include <io.h>
 #include <windows.h>
 #include <process.h>
@@ -62,7 +62,7 @@
 #include "timip_playmidi.h"
 #include "timip_readmidi.h"
 
-#if defined(__W32__) && !defined ( IA_W32GUI ) && !defined ( IA_W32G_SYN )
+#if defined(TIMIP___W32__) && !defined ( IA_W32GUI ) && !defined ( IA_W32G_SYN )
 #include "timip_w32g.h" //for crt_beginthreadex();
 #endif
 
@@ -119,7 +119,7 @@ volatile extern int w32g_auto_output_mode;
 extern int gogo_ConfigDialogInfoApply(void);
 #endif
 
-#ifdef __W32__
+#ifdef TIMIP___W32__
 volatile static HANDLE hMPGEthread = NULL;
 volatile static HANDLE hMutexgogo = NULL;
 volatile static DWORD dwMPGEthreadID = 0;
@@ -203,7 +203,7 @@ extern char *timip_create_auto_output_name(const char *input_filename, char *ext
 volatile static int gogo_lock_flag = 0;
 static int gogo_lock()
 {
-#ifndef __W32__
+#ifndef TIMIP___W32__
 	while(gogo_lock_flag){
 		usleep(100);
 	}
@@ -224,7 +224,7 @@ static int gogo_lock()
 
 static int gogo_unlock()
 {
-#ifndef __W32__
+#ifndef TIMIP___W32__
 	if(gogo_lock_flag)
 		gogo_lock_flag--;
 	return 0;
@@ -386,7 +386,7 @@ static int __cdecl gogoUserFunc(char *buf, unsigned long nLength )
 		}
 		if(gogo_buffer_cur_size<=0){
 			gogo_unlock();
-#ifndef __W32__
+#ifndef TIMIP___W32__
 			usleep(100);
 #else
 			Sleep(0);
@@ -1094,7 +1094,7 @@ static int __stdcall MPGEthread(void)
 // Whether the thread timip_of gogo.dll is terminated ?
 static int IsTerminatedMPGEthread(void)
 {
-#ifndef __W32__
+#ifndef TIMIP___W32__
 #else
 	DWORD dwRes;
 	if(hMPGEthread==NULL)
@@ -1114,7 +1114,7 @@ static int CreateMPGEthread(void)
 	// gogo ѤΥåɤλƤ뤫ǧ롣
 	gogo_buffer_termination  = 1;
 	while(!IsTerminatedMPGEthread()){
-#ifndef __W32__
+#ifndef TIMIP___W32__
 		usleep(100);
 #else
 		Sleep(0);
@@ -1124,7 +1124,7 @@ static int CreateMPGEthread(void)
 	gogo_buffer_termination  = 0;
 
 	// gogo ѤΥåɤ롣
-#ifndef __W32__
+#ifndef TIMIP___W32__
 
 #else
 	// ϥɥϥƤ
@@ -1217,14 +1217,14 @@ static int auto_gogo_output_open(const char *input_filename, const char *title)
   return 0;
 }
 
-#ifdef AU_GOGO_DLL	
+#ifdef TIMIP_AU_GOGO_DLL	
 extern int gogo_dll_check(void);
 #endif
 static int open_output(void)
 {
     int include_enc, exclude_enc;
 
-#ifdef AU_VORBIS_DLL
+#ifdef TIMIP_AU_VORBIS_DLL
 	if(!gogo_dll_check()){
 		timip_ctl->cmsg(CMSG_ERROR, VERB_NORMAL, "can not find gogo.dll.");
 		return -1;
@@ -1311,7 +1311,7 @@ static int output_data(char *readbuffer, int32 bytes)
 		out_bytes += size;
 		gogo_unlock();
 		if(bytes>0){
-#ifndef __W32__
+#ifndef TIMIP___W32__
 			usleep(100);
 #else
 			Sleep(0);
@@ -1332,7 +1332,7 @@ static void close_output(void)
     if (IsTerminatedMPGEthread()) {
       break;
     }
-#ifndef __W32__
+#ifndef TIMIP___W32__
     usleep(100000);
 #else
     Sleep(100);
