@@ -23,7 +23,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #include <stdlib.h>
@@ -1362,7 +1362,8 @@ static void free_tone_bank_list(ToneBank *tb[])
 	int i, j;
 	ToneBank *bank;
 	
-	for (i = 0; i < 128 + map_bank_counter; i++)
+//	for (i = 0; i < 128 + map_bank_counter; i++)
+	for (i = 0; i < 256; i++)   /* Fix me is this true? But my soundfont have bank 255 */
 	{
 		bank = tb[i];
 		if (!bank)
@@ -1455,12 +1456,13 @@ void timip_free_tone_bank_element(ToneBankElement *elm)
 
 void timip_free_instruments(int reload_default_inst)
 {
-    int i = 128 + map_bank_counter, j;
+    int i = 128 + map_bank_counter, j, k;
     struct InstrumentCache *p;
     ToneBank *bank;
     Instrument *timip_ip;
     struct InstrumentCache *default_entry;
-    int default_entry_addr;
+    int default_entry_addr;;
+
 
     timip_clear_magic_instruments();
 
@@ -1489,6 +1491,11 @@ void timip_free_instruments(int reload_default_inst)
 		    timip_free_instrument(timip_ip);
 		bank->tone[j].instrument = NULL;
 	    }
+	 if( (timip_drumset[i] != NULL) && (timip_drumset[i]->alt != NULL))
+    	{
+		free(timip_drumset[i]->alt);
+		timip_drumset[i]->alt=NULL;
+		}
     }
 
     /* Free GUS/patch instruments */
