@@ -24,7 +24,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include	<Sound.h>
 #include	<stdio.h>
@@ -58,12 +58,12 @@
 #endif
 
 #define MAIN_INTERFACE  /* non-static */
-MAIN_INTERFACE void	timip_timidity_start_initialize(void);
-MAIN_INTERFACE int	timip_timidity_pre_load_configuration(void);
-MAIN_INTERFACE int	timip_timidity_post_load_configuration(void);
-MAIN_INTERFACE void	timip_timidity_init_player(void);
-MAIN_INTERFACE int	timip_timidity_play_main(int nfiles, char **files);
-MAIN_INTERFACE int	timip_read_config_file(char *name, int self);
+MAIN_INTERFACE void	timidity_start_initialize(void);
+MAIN_INTERFACE int	timidity_pre_load_configuration(void);
+MAIN_INTERFACE int	timidity_post_load_configuration(void);
+MAIN_INTERFACE void	timidity_init_player(void);
+MAIN_INTERFACE int	timidity_play_main(int nfiles, char **files);
+MAIN_INTERFACE int	read_config_file(char *name, int self);
 MAIN_INTERFACE void	timip_timidity_init_aq_buff(void);
 
 extern char *timip_wrdt_open_opts;
@@ -209,10 +209,10 @@ int  main()
 		timip_opt_aq_fill_buff = timip_safe_strdup("100%");
 #endif
 	
-	timip_timidity_start_initialize();
-	if((timip_err = timip_timidity_pre_load_configuration()) != 0)
+	timidity_start_initialize();
+	if((timip_err = timidity_pre_load_configuration()) != 0)
 		return timip_err;
-	timip_err += timip_timidity_post_load_configuration();
+	timip_err += timidity_post_load_configuration();
 	if( timip_err )
 	{
 		//timip_ctl->cmsg(CMSG_ERROR, VERB_NORMAL,
@@ -220,11 +220,11 @@ int  main()
 		return 1; /* problems with command line */
 	}
 	
-	timip_timidity_init_player();
+	timidity_init_player();
 	timip_wrdt=timip_wrdt_list[0];  //dirty!!
 	timip_wrdt_open_opts= "m";
-	timip_timidity_play_main(0, NULL);
-	 	//CPU won't return from timip_timidity_play_main
+	timidity_play_main(0, NULL);
+	 	//CPU won't return from timidity_play_main
 	return 0;
 }
 
