@@ -22,7 +22,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include "timip_timidity.h"
 #include "timip_common.h"
