@@ -21,7 +21,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <math.h>
 #include <stdio.h>
@@ -167,7 +167,11 @@ void timip_mix_voice(int32 *buf, int v, int32 c)
 }
 
 /* return 1 if filter is enabled. */
+#ifdef __BORLANDC__
+static int do_voice_filter(int v, resample_t *sp, mix_t *lp, int32 count)
+#else
 static inline int do_voice_filter(int v, resample_t *sp, mix_t *lp, int32 count)
+#endif
 {
 	FilterCoefficients *fc = &(timip_voice[v].fc);
 	int32 i, f, q, p, b0, b1, b2, b3, b4, t1, t2, x;
@@ -250,7 +254,11 @@ static inline void recalc_voice_fc(int v)
 }
 
 /* Ramp a note out in c samples */
+#ifdef __BORLANDC__
+static void ramp_out(mix_t *sp, int32 *lp, int v, int32 c)
+#else
 static inline void ramp_out(mix_t *sp, int32 *lp, int v, int32 c)
+#endif
 {
 	/* should be final_volume_t, but uint8 gives trouble. */
 	int32 left, right, li, ri, i;
@@ -366,8 +374,13 @@ static inline void ramp_out(mix_t *sp, int32 *lp, int v, int32 c)
 		}
 }
 
+#ifdef __BORLANDC__
+static void mix_mono_signal(
+		mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_mono_signal(
 		mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	Voice *vp = timip_voice + v;
 	final_volume_t left = vp->left_mix;
@@ -460,7 +473,11 @@ static inline void mix_mono_signal(
 		}
 }
 
+#ifdef __BORLANDC__
+static void mix_mono(mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_mono(mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	final_volume_t left = timip_voice[v].left_mix;
 	mix_t s;
@@ -503,8 +520,13 @@ static inline void mix_mono(mix_t *sp, int32 *lp, int v, int count)
 }
 
 #ifdef ENABLE_PAN_DELAY
+#ifdef __BORLANDC__
+static void mix_mystery_signal(
+		mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_mystery_signal(
 		mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	Voice *vp = timip_voice + v;
 	final_volume_t left = vp->left_mix, right = vp->right_mix;
@@ -931,7 +953,11 @@ static inline void mix_mystery_signal(
 #endif	/* ENABLE_PAN_DELAY */
 
 #ifdef ENABLE_PAN_DELAY
+#ifdef __BORLANDC__
+static void mix_mystery(mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_mystery(mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	final_volume_t left = timip_voice[v].left_mix, right = timip_voice[v].right_mix;
 	mix_t s;
@@ -1134,8 +1160,13 @@ static inline void mix_mystery(mix_t *sp, int32 *lp, int v, int count)
 #endif	/* ENABLE_PAN_DELAY */
 
 
+#ifdef __BORLANDC__
+static void mix_center_signal(
+		mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_center_signal(
 		mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	Voice *vp = timip_voice + v;
 	final_volume_t left=vp->left_mix;
@@ -1232,7 +1263,11 @@ static inline void mix_center_signal(
 		}
 }
 
+#ifdef __BORLANDC__
+static void mix_center(mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_center(mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	final_volume_t left = timip_voice[v].left_mix;
 	mix_t s;
@@ -1275,8 +1310,13 @@ static inline void mix_center(mix_t *sp, int32 *lp, int v, int count)
 	}
 }
 
+#ifdef __BORLANDC__
+static void mix_single_signal(
+		mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_single_signal(
 		mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	Voice *vp = timip_voice + v;
 	final_volume_t left = vp->left_mix;
@@ -1373,7 +1413,11 @@ static inline void mix_single_signal(
 		}
 }
 
+#ifdef __BORLANDC__
+static void mix_single(mix_t *sp, int32 *lp, int v, int count)
+#else
 static inline void mix_single(mix_t *sp, int32 *lp, int v, int count)
+#endif
 {
 	final_volume_t left = timip_voice[v].left_mix;
 	mix_t s;
@@ -1417,7 +1461,11 @@ static inline void mix_single(mix_t *sp, int32 *lp, int v, int count)
 }
 
 /* Returns 1 if the note died */
+#ifdef __BORLANDC__
+static int update_signal(int v)
+#else
 static inline int update_signal(int v)
+#endif
 {
 	Voice *vp = &timip_voice[v];
 
@@ -1430,7 +1478,11 @@ static inline int update_signal(int v)
 	return timip_apply_envelope_to_amp(v);
 }
 
+#ifdef __BORLANDC__
+static int update_envelope(int v)
+#else
 static inline int update_envelope(int v)
+#endif
 {
 	Voice *vp = &timip_voice[v];
 	
@@ -1568,7 +1620,11 @@ static inline void voice_ran_out(int v)
 		timip_ctl_note_event(v);
 }
 
+#ifdef __BORLANDC__
+static int next_stage(int v)
+#else
 static inline int next_stage(int v)
+#endif
 {
 	int stage, ch, eg_stage;
 	int32 offset, val;
@@ -1658,7 +1714,11 @@ static inline int next_stage(int v)
 	return 0;
 }
 
+#ifdef __BORLANDC__
+static void update_tremolo(int v)
+#else
 static inline void update_tremolo(int v)
+#endif
 {
 	Voice *vp = &timip_voice[v];
 	int32 depth = vp->tremolo_depth << 7;
@@ -1778,7 +1838,11 @@ int timip_apply_envelope_to_amp(int v)
 }
 
 #ifdef SMOOTH_MIXING
+#ifdef __BORLANDC__
 static inline void compute_mix_smoothing(Voice *vp)
+#else
+static inline void compute_mix_smoothing(Voice *vp)
+#endif
 {
 	int32 max_win, delta;
 	
@@ -1807,7 +1871,11 @@ static inline void compute_mix_smoothing(Voice *vp)
 }
 #endif
 
+#ifdef __BORLANDC__
+static int update_modulation_envelope(int v)
+#else
 static inline int update_modulation_envelope(int v)
+#endif
 {
 	Voice *vp = &timip_voice[v];
 
