@@ -25,7 +25,7 @@
 /* Interface to libunimod + module player */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
