@@ -21,7 +21,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <math.h>
 #include <stdio.h>
@@ -436,8 +436,9 @@ void timip_initialize_gauss_table(int n)
     	zsin[i] = sin(i / (4*M_PI));
 
     x_inc = 1.0 / (1<<FRACTION_BITS);
-    gptr = timip_safe_realloc(gauss_table[0], (n+1)*sizeof(float)*(1<<FRACTION_BITS));
-    for (m = 0, x = 0.0; m < (1<<FRACTION_BITS); m++, x += x_inc)
+//    gptr = timip_safe_realloc( gauss_table[0], (n+1)*sizeof(float)*(1<<FRACTION_BITS)); //why this need realloc? This cause memory leak.
+    gptr = timip_safe_malloc(  (n+1)*sizeof(float)*(1<<FRACTION_BITS));
+	for (m = 0, x = 0.0; m < (1<<FRACTION_BITS); m++, x += x_inc)
     {
     	xz = (x + n_half) / (4*M_PI);
     	for (i = 0; i <= n; i++)
@@ -460,7 +461,10 @@ void timip_initialize_gauss_table(int n)
     	}
     }
 }
-
+void timip_free_gauss_table(void)
+{
+		 free(gauss_table[0]);
+}
 #if 0 /* NOT USED */
 /* the was calculated statically in newton_table.c */
 static void initialize_newton_coeffs(void)
