@@ -44,7 +44,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #ifndef NO_STRING_H
@@ -746,7 +746,7 @@ static void free_layer(SFHeader *hdr)
 	int i;
 	for (i = 0; i < hdr->nlayers; i++) {
 		SFGenLayer *layp = &hdr->layer[i];
-		if (layp->nlists > 0)
+		if (layp->nlists >= 0)
 			free(layp->list);
 	}
 	if (hdr->nlayers > 0)
