@@ -1,36 +1,35 @@
 /*
     TiMidity++ -- MIDI to WAVE converter and player
-    Copyright (C) 1999-2002 Masanao Izumo <mo@goice.co.jp>
+    Copyright (C) 1999-2005 Masanao Izumo <iz@onicos.co.jp>
     Copyright (C) 1995 Tuukka Toivonen <tt@cgs.fi>
+
+    This program is free software; you can redistribute it and/or modify
+    it under the terms timip_of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 timip_of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty timip_of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy timip_of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+
+    This code from awesfx
+    Modified by Masanao Izumo <mo@goice.co.jp>
+
+    ================================================================
+    parsesf.c
+         parse SoundFont layers and convert it to AWE driver patch
+
+    Copyright (C) 1996,1997 Takashi Iwai
+    ================================================================
 */
 
-/* This code from awesfx
- * Modified by Masanao Izumo <mo@goice.co.jp>
- */
-
-/*================================================================
- * parsesf.c
- *	parse SoundFonr layers and convert it to AWE driver patch
- *
- * Copyright (C) 1996,1997 Takashi Iwai
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms timip_of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 timip_of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty timip_of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy timip_of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *================================================================*/
-
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #ifndef NO_STRING_H
@@ -55,6 +54,7 @@
 #include "timip_output.h"
 #include "timip_filter.h"
 #include "timip_resample.h"
+#include "timip_interface.h"
 
 #define FILENAME_NORMALIZE(fname) timip_url_expand_home_dir(fname)
 #define FILENAME_REDUCED(fname)   timip_url_unexpand_home_dir(fname)
@@ -66,11 +66,12 @@
  *----------------------------------------------------------------*/
 
 #ifdef CFG_FOR_SF
+#define SF_CLOSE_EACH_FILE 0
 #define SF_SUPPRESS_ENVELOPE
 #define SF_SUPPRESS_TREMOLO
 #define SF_SUPPRESS_VIBRATO
 #else
-#define SF_CLOSE_EACH_FILE
+#define SF_CLOSE_EACH_FILE 1
 /*#define SF_SUPPRESS_ENVELOPE*/
 /*#define SF_SUPPRESS_TREMOLO*/
 /*#define SF_SUPPRESS_VIBRATO*/
@@ -209,6 +210,7 @@ static void convert_vibrato(SampleList *vp, LayerTable *tbl);
 
 /*----------------------------------------------------------------*/
 
+int timip_opt_sf_close_each_file = SF_CLOSE_EACH_FILE;
 static SFInsts *sfrecs = NULL;
 static SFInsts *current_sfrec = NULL;
 #define def_drum_inst 0
@@ -274,6 +276,18 @@ void timip_remove_soundfont(char *sf_file)
 	end_soundfont(sf);
 }
 
+void timip_free_soundfonts()
+{
+	SFInsts *sf, *next;
+	
+	for(sf = sfrecs; sf != NULL; sf = next){
+		if((sf->tf != NULL) && (sf->tf->url != NULL)) free(sf->tf->url);
+		if(sf->tf != NULL)free(sf->tf);
+		timip_reuse_mblock( & sf->pool);
+		next = sf->next;
+		free (sf);
+	}
+}
 char *timip_soundfont_preset_name(int bank, int preset, int keynote,
 			    char **sndfile)
 {
@@ -331,7 +345,7 @@ static void init_sf(SFInsts *rec)
 
 		if (bank == 128)
 		    /* FIXME: why not allow exclusion timip_of drumsets? */
-		    timip_alloc_instrument_bank(1, preset);
+			timip_alloc_instrument_bank(1, preset);
 		else {
 			if (is_excluded(rec, bank, preset, -1))
 				continue;
@@ -352,12 +366,14 @@ static void init_sf(SFInsts *rec)
 		(char *)SFStrdup(rec, sfinfo.preset[i].hdr.name);
 	timip_free_soundfont(&sfinfo);
 
-#ifndef SF_CLOSE_EACH_FILE
-	if(!IS_URL_SEEK_SAFE(rec->tf->url))
-#endif
-	{
-	    timip_close_file(rec->tf);
-	    rec->tf = NULL;
+	if (! timip_opt_sf_close_each_file) {
+		if (! IS_URL_SEEK_SAFE(rec->tf->url)) {
+			timip_close_file(rec->tf);
+			rec->tf = NULL;
+		}
+	} else {
+		timip_close_file(rec->tf);
+		rec->tf = NULL;
 	}
 }
 
@@ -419,10 +435,9 @@ static Instrument *try_load_soundfont(SFInsts *rec, int order, int bank,
 			end_soundfont(rec);
 			return NULL;
 		}
-#ifndef SF_CLOSE_EACH_FILE
-		if(!IS_URL_SEEK_SAFE(rec->tf->url))
-		    rec->tf->url = timip_url_cache_open(rec->tf->url, 1);
-#endif /* SF_CLOSE_EACH_FILE */
+		if (! timip_opt_sf_close_each_file)
+			if (! IS_URL_SEEK_SAFE(rec->tf->url))
+				rec->tf->url = timip_url_cache_open(rec->tf->url, 1);
 	}
 
 	addr = INSTHASH(bank, preset, keynote);
@@ -436,10 +451,10 @@ static Instrument *try_load_soundfont(SFInsts *rec, int order, int bank,
 	if (timip_ip && timip_ip->samples)
 		inst = load_from_file(rec, timip_ip);
 
-#ifdef SF_CLOSE_EACH_FILE
-	timip_close_file(rec->tf);
-	rec->tf = NULL;
-#endif
+	if (timip_opt_sf_close_each_file) {
+		timip_close_file(rec->tf);
+		rec->tf = NULL;
+	}
 
 	return inst;
 }
@@ -1839,7 +1854,7 @@ extern struct URL_module timip_URL_module_newsgroup;
 #ifdef HAVE_POPEN
 extern struct URL_module timip_URL_module_pipe;
 #endif /* HAVE_POPEN */
-static struct URL_module *timip_url_module_list[] =
+static struct URL_module *url_module_list[] =
 {
     &timip_URL_module_file,
 #ifndef __MACOS__
@@ -2020,8 +2035,8 @@ int main(int argc, char **argv)
 	    strcat(timip_url_user_agent, timip_timidity_version);
 	}
 #endif /* SUPPORT_SOCKET */
-	for(i = 0; timip_url_module_list[i]; i++)
-	    timip_url_add_module(timip_url_module_list[i]);
+	for(i = 0; url_module_list[i]; i++)
+	    timip_url_add_module(url_module_list[i]);
 	timip_init_freq_table();
 	timip_init_bend_fine();
 	timip_init_bend_coarse();
