@@ -23,7 +23,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #include <stdio.h>
 #if HAVE_UNISTD_H
@@ -211,8 +211,8 @@ void speex_set_option_nframes(int nframes)
 int oe_write_page(ogg_page *page, int fd)
 {
   int written = 0;
-  written += write(fd, page->header, page->header_len);
-  written += write(fd, page->body,   page->body_len);
+  written += timip_std_write(fd, page->header, page->header_len);
+  written += timip_std_write(fd, page->body,   page->body_len);
 
   return written;
 }
