@@ -20,7 +20,7 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 #ifndef PACKAGE_VERSION
 #define PACKAGE_VERSION TIMID_VERSION
