@@ -25,10 +25,10 @@
 */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
-#ifdef __W32__
-#include "interface.h"
+#ifdef TIMIP___W32__
+#include "timip_interface.h"
 #endif
 #include <stdio.h>
 #include <stdlib.h>
@@ -132,7 +132,7 @@ MMRESULT WINAPI waveOutGetID(HWAVEOUT, UINT*);
 #include "timip_playmidi.h"
 #include "timip_mblock.h"
 #include "timip_miditrace.h"
-#include "interface.h"
+#include "timip_interface.h"
 
 #define NOT !
 
@@ -215,7 +215,7 @@ static int open_output(void)
     WAVEFORMATEX    wf;
     WAVEOUTCAPS     woc;
     MMRESULT        Result;
-    UINT            timip_DeviceID;
+    UINT            DeviceID;
 
     if (dpm.extra_param[0] < 8)
     {
@@ -297,15 +297,15 @@ static int open_output(void)
 
 /** Get the device ID. **/
 
-    timip_DeviceID = 0;
-    waveOutGetID(hDevice, &timip_DeviceID);
+    DeviceID = 0;
+    waveOutGetID(hDevice, &DeviceID);
 
 /** Get the device capabilities. **/
 
     memset(&woc, 0, sizeof(WAVEOUTCAPS));
-    Result = waveOutGetDevCaps(timip_DeviceID, &woc, sizeof(WAVEOUTCAPS));
+    Result = waveOutGetDevCaps(DeviceID, &woc, sizeof(WAVEOUTCAPS));
 
-    timip_ctl->cmsg(CMSG_INFO, VERB_DEBUG, "Device ID: %d",              timip_DeviceID);
+    timip_ctl->cmsg(CMSG_INFO, VERB_DEBUG, "Device ID: %d",              DeviceID);
     timip_ctl->cmsg(CMSG_INFO, VERB_DEBUG, "Manufacture ID: %d",         woc.wMid);
     timip_ctl->cmsg(CMSG_INFO, VERB_DEBUG, "Product ID: %d",             woc.wPid);
     timip_ctl->cmsg(CMSG_INFO, VERB_DEBUG, "Driver version: %d",         woc.vDriverVersion);
