@@ -4,26 +4,26 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 
-#if !defined(HAVE_GETOPT_LONG) || !defined(HAVE_GETOPT)
+#if !defined(TIMIP_HAVE_GETOPT_LONG) || !defined(TIMIP_HAVE_GETOPT)
 
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_UNISTD_H
+#ifdef TIMIP_HAVE_UNISTD_H
 #include <unistd.h>
-#endif /* HAVE_UNISTD_H */
+#endif /* TIMIP_HAVE_UNISTD_H */
 #include <string.h>
 
 #include "timip_tmdy_getopt.h"
 
-#ifndef HAVE_GETOPT
+#ifndef TIMIP_HAVE_GETOPT
 char *optarg;
 int optind = 1;
 int opterr = 1;
 int optopt = '?';
-#endif /* HAVE_GETOPT */
+#endif /* TIMIP_HAVE_GETOPT */
 
 static enum
 {
@@ -198,7 +198,7 @@ _getopt_initialize (int argc, char *const*argv, const char *optstring)
 
 static int
 _getopt_internal (int argc, char *const*argv, const char *optstring,
-		  const struct option *longopts, int *longind, int long_only)
+		  const struct option *timip_longopts, int *longind, int long_only)
 {
   int print_errors = opterr;
   if (optstring[0] == ':')
@@ -297,7 +297,7 @@ _getopt_internal (int argc, char *const*argv, const char *optstring,
 	 Skip the initial punctuation.  */
 
       nextchar = (argv[optind] + 1
-		  + (longopts != NULL && argv[optind][1] == '-'));
+		  + (timip_longopts != NULL && argv[optind][1] == '-'));
     }
 
   /* Decode the current option-ARGV-element.  */
@@ -315,7 +315,7 @@ _getopt_internal (int argc, char *const*argv, const char *optstring,
 
      This distinction seems to be the most useful approach.  */
 
-  if (longopts != NULL
+  if (timip_longopts != NULL
       && (argv[optind][1] == '-'
 	  || (long_only && (argv[optind][2] || !strchr (optstring, argv[optind][1])))))
     {
@@ -332,7 +332,7 @@ _getopt_internal (int argc, char *const*argv, const char *optstring,
 
       /* Test all long options for either exact match
 	 or abbreviated matches.  */
-      for (p = longopts, option_index = 0; p->name; p++, option_index++)
+      for (p = timip_longopts, option_index = 0; p->name; p++, option_index++)
 	if (!strncmp (p->name, nextchar, nameend - nextchar))
 	  {
 	    if ((unsigned int) (nameend - nextchar)
@@ -517,14 +517,14 @@ _getopt_internal (int argc, char *const*argv, const char *optstring,
 	  optarg = argv[optind++];
 
 	/* optarg is now the argument, see if it's in the
-	   table timip_of longopts.  */
+	   table timip_of timip_longopts.  */
 
 	for (nextchar = nameend = optarg; *nameend && *nameend != '='; nameend++)
 	  /* Do nothing.  */ ;
 
 	/* Test all long options for either exact match
 	   or abbreviated matches.  */
-	for (p = longopts, option_index = 0; p->name; p++, option_index++)
+	for (p = timip_longopts, option_index = 0; p->name; p++, option_index++)
 	  if (!strncmp (p->name, nextchar, nameend - nextchar))
 	    {
 	      if ((unsigned int) (nameend - nextchar) == strlen (p->name))
@@ -651,7 +651,7 @@ _getopt_internal (int argc, char *const*argv, const char *optstring,
   }
 }
 
-#ifndef HAVE_GETOPT_LONG
+#ifndef TIMIP_HAVE_GETOPT_LONG
 int
 getopt_long (int argc, char *const *argv, const char *options,
 	     const struct option *long_options, int *opt_index)
@@ -672,7 +672,7 @@ getopt_long_only (int argc, char *const *argv, const char *options,
 }
 #endif
 
-#ifndef HAVE_GETOPT
+#ifndef TIMIP_HAVE_GETOPT
 int
 getopt (int argc, char *const *argv, const char *optstring)
 {
