@@ -23,7 +23,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include "timip_config.h"
 #endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
@@ -43,9 +43,9 @@
 #else
 #include <strings.h>
 #endif
-#ifdef __W32__
+#ifdef TIMIP___W32__
 #include <windows.h>
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
@@ -607,7 +607,7 @@ char *strerror(int errnum)
 #endif /* HAVE_STRERROR */
 
 #ifndef HAVE_USLEEP
-#ifdef __W32__
+#ifdef TIMIP___W32__
 int usleep(unsigned int usec)
 {
     Sleep(usec / 1000);
@@ -628,7 +628,7 @@ int usleep(unsigned int usec)
     select(0, NULL, NULL, NULL, &tv);
     return 0;
 }
-#endif /* __W32__ */
+#endif /* TIMIP___W32__ */
 #endif /* HAVE_USLEEP */
 
 #ifndef HAVE_STRDUP
@@ -825,3 +825,19 @@ timip_strlcat(char *dst, const char *src, size_t siz)
 	return(dlen + (s - src));	/* count does not include NUL */
 }
 #endif  /* timip_strlcat() */
+
+#ifdef __DMC__
+int strcasecmp(const char *s1, const char *s2)
+{
+	int	c1,c2,i;
+	
+	for( i=0; ; i++){
+		if( !s1[i] && !s2[i] ) return 0; //equal
+		if( !s1[i] || !s2[i] ) return 1;
+		c1= ( isupper(s1[i]) ? tolower(s1[i]) : s1[i] );
+		c2= ( isupper(s2[i]) ? tolower(s2[i]) : s2[i] );
+		if( c1 != c2 )	return 1;
+	}
+	return 0; //equal
+}
+#endif
